@@ -10,21 +10,27 @@
 """
 
 import sys
+import pickle
 import posixpath
 from os import path
 
-from six.moves import cPickle as pickle
 from jinja2 import Environment, FileSystemLoader
 from docutils.core import publish_parts
 
 from sphinx.locale import _
+from sphinx.util.docutils import docutils_namespace
 from sphinx.util.osutil import ensuredir
-from sphinx.util.jsonimpl import dumps as dump_json
 from sphinx.util.pycompat import htmlescape
 from sphinxcontrib.websupport import errors
+from sphinxcontrib.websupport import package_dir
 from sphinxcontrib.websupport.search import BaseSearch, SEARCH_ADAPTERS
 from sphinxcontrib.websupport.storage import StorageBackend
 
+try:
+    from sphinxcontrib.serializinghtml.jsonimpl import dumps as dump_json
+except ImportError:
+    from sphinx.util.jsonimpl import dumps as dump_json
+
 if False:
     # For type annotation
     from typing import Dict  # NOQA
@@ -42,6 +48,8 @@ class WebSupport(object):
                  doctreedir=None,  # defaults to builddir/doctrees
                  search=None,      # defaults to no search
                  storage=None,     # defaults to SQLite in datadir
+                 buildername='websupport',
+                 confoverrides={},
                  status=sys.stdout,
                  warning=sys.stderr,
                  moderation_callback=None,
@@ -60,6 +68,9 @@ class WebSupport(object):
         self.staticroot = staticroot.strip('/')
         self.docroot = docroot.strip('/')
 
+        self.buildername = buildername
+        self.confoverrides = confoverrides
+
         self.status = status
         self.warning = warning
         self.moderation_callback = moderation_callback
@@ -73,6 +84,9 @@ class WebSupport(object):
 
         self._make_base_comment_options()
 
+        extensions = self.confoverrides.setdefault('extensions', [])
+        extensions.append('sphinxcontrib.websupport.builder')
+
     def _init_storage(self, storage):
         if isinstance(storage, StorageBackend):
             self.storage = storage
@@ -89,10 +103,7 @@ class WebSupport(object):
             self.storage = SQLAlchemyStorage(storage)
 
     def _init_templating(self):
-        import sphinx
-        template_path = path.join(sphinx.package_dir,
-                                  'themes', 'basic')
-        loader = FileSystemLoader(template_path)
+        loader = FileSystemLoader(path.join(package_dir, 'templates'))
         self.template_env = Environment(loader=loader)
 
     def _init_search(self, search):
@@ -121,15 +132,17 @@ class WebSupport(object):
         if not self.srcdir:
             raise RuntimeError('No srcdir associated with WebSupport object')
 
-        from sphinx.application import Sphinx
-        app = Sphinx(self.srcdir, self.srcdir, self.outdir, self.doctreedir,
-                     'websupport', status=self.status, warning=self.warning)
-        app.builder.set_webinfo(self.staticdir, self.staticroot,  # type: ignore
-                                self.search, self.storage)
+        with docutils_namespace():
+            from sphinx.application import Sphinx
+            app = Sphinx(self.srcdir, self.srcdir, self.outdir, self.doctreedir,
+                         self.buildername, self.confoverrides, status=self.status,
+                         warning=self.warning)
+            app.builder.set_webinfo(self.staticdir, self.staticroot,  # type: ignore
+                                    self.search, self.storage)
 
-        self.storage.pre_build()
-        app.build()
-        self.storage.post_build()
+            self.storage.pre_build()
+            app.build()
+            self.storage.post_build()
 
     def get_globalcontext(self):
         """Load and return the "global context" pickle."""
@@ -389,7 +402,7 @@ class WebSupport(object):
         that remains the same throughout the lifetime of the
         :class:`~sphinxcontrib.websupport.WebSupport` object.
         """
-        self.base_comment_opts = {}  # type: Dict[unicode, unicode]
+        self.base_comment_opts = {}  # type: Dict[str, str]
 
         if self.docroot != '':
             comment_urls = [
